function out = momfunc_Equidep( U , q )
% function out = momfunc_Equidep( U , q )
%
% Function to compute the average pair-wise rank correlation and quantile
% dependence between the U data, for use in SMM estimation. 
%
% INPUTS:   U, a TxN matrix of Unif(0,1) data. 
%           q, a Qx1 vector of quantiles at which to evaluate the quantile dependence function
%
% OUTPUTS:  out, a (Q+1)x1 vector of the rank correlation and quantile dependence measures for this data
% 
%  Dong Hwan Oh and Andrew J. Patton
%
%  22 October 2013
%
% This code was developed for the following paper:
%
% Oh, D.H. and A.J. Patton, 2013, "Simulated Method of Moments Estimation
% for Copula-Based Multivariate Models," Journal of the American
% Statistical Association, 108(502), 689-700.


[T,N] = size(U);

if nargin<2 || isempty(q)
    q = [0.05,0.1,0.90,0.95];
end
Q = length(q);

m = zeros(Q+1,1) ;

for i = 1:(N-1)
    for j = i+1:N        
        m(1) = m(1) + sum(   mSrho( U(:,i), U(:,j) )      )/T ;
%         m(2) = m(2) + sum(   mQdep( U(:,i), U(:,j), q(1) ) )/T ;
%         m(3) = m(3) + sum(   mQdep( U(:,i), U(:,j), q(2) ) )/T ;
%         m(4) = m(4) + sum(   mQdep( U(:,i), U(:,j), q(3) ) )/T ;
%         m(5) = m(5) + sum(   mQdep( U(:,i), U(:,j), q(4) ) )/T ;
        for k = 1:Q
           m(k+1) = m(k+1) + sum( mQdep( U(:,i), U(:,j), q(k) ) )/T ;
        end
    end
end

out = m/(N*(N-1)/2) ;

 

