% This script to calculate count frequencies of DM test based on VaR(T,N,R)
% Author: Fang Duan
% created on March, 2019
% updated on June, 2019 add loss for each model/moment combi in response to
% editor's comments
% NOTE: The output .mat files from 'MAIN_sim2.m' serves as the input .mat
% (Workspace) to be loaded. Hence, one needs to generate the .mat files for
% all 20 combinations before run this code.

clear
addmypath;

% parameters
N = 5; % N = 10
T = 1500;
R = 100;
pval = [0.05,0.01];

simfunc_true = 'simfunc_skewtt';
theta_null = [1 0.25 -0.5];
dpd = 'Equidep_theta';
phi= [0.01, 0.05, 0.05, 0.10, 0.85];

% simulate the true data series
data_VaR0 = NaN(T,N,R);
for index = 1:R
    disp(strcat('Round:',num2str(index)))
    seed = index;
    other = [T N seed];    
    [data_VaR0(:,:,index), uresid] = simulate_return(simfunc_true, theta_null, other, dpd, phi);
end

% 20 combinations
moments = {'lower', 'left', 'tail', 'center', 'whole'};
models = {'gaussian', 'skewnn', 'tt', 'skewtt'};
EstimationWindowSize = 1000;
TestWindow = 1001 : T;

% generate 20 combinations
combi = [];
for idx_i = 1:4
    for idx_j = 1:5
         combi = [combi ; {models{idx_i}, moments{idx_j}}];
    end
end

count1_005 = zeros(20,20); % count number when model 1 is preferred
count2_005 = zeros(20,20); % count number when model 2 is preferred
count1_001 = zeros(20,20); 
count2_001 = zeros(20,20); 
for ii_var = 1:19
    for jj_var = (ii_var+1):20
        load(strcat('Workspace_', combi{ii_var,2},'_simfunc_', combi{ii_var,1}, '_N', num2str(N), '.mat'))
        VaR1 = VaR;
        load(strcat('Workspace_', combi{jj_var,2},'_simfunc_', combi{jj_var,1}, '_N', num2str(N), '.mat'))
        VaR2 = VaR;
        for index = 1:R
            disp(strcat('Round:',num2str(index)))
            temp_return = log(1+mean( exp(data_VaR0(:,:,index))-1, 2 ));
            e1_005 = loss_VaR(VaR1(:,1,index),temp_return,TestWindow, pval(1));
            e2_005 = loss_VaR(VaR2(:,1,index),temp_return,TestWindow, pval(1));
            e1_001 = loss_VaR(VaR1(:,2,index),temp_return,TestWindow, pval(2));
            e2_001 = loss_VaR(VaR2(:,2,index),temp_return,TestWindow, pval(2));
            if dmtest(e1_005',e2_005',1) < -1.96
                count1_005(ii_var,jj_var) =  count1_005(ii_var,jj_var) + 1;
            elseif dmtest(e1_005',e2_005',1) > 1.96
                count2_005(ii_var,jj_var) =  count2_005(ii_var,jj_var) + 1;
            end
            if dmtest(e1_001',e2_001',1) < -1.96
                count1_001(ii_var,jj_var) =  count1_001(ii_var,jj_var) + 1;
            elseif dmtest(e1_001',e2_001',1) > 1.96
                count2_001(ii_var,jj_var) =  count2_001(ii_var,jj_var) + 1;
            end
        end
    end    
end

temp_loss = zeros(R,2);
loss = zeros(20,2);
for ii_var = 1:20
    load(strcat('Workspace_', combi{ii_var,2},'_simfunc_', combi{ii_var,1}, '_N', num2str(N), '.mat'))
    VaR1 = VaR;
    for index = 1:R
        disp(strcat('Round:',num2str(index)))
        temp_return = log(1+mean( exp(data_VaR0(:,:,index))-1, 2 ));
        e1_005 = loss_VaR(VaR1(:,1,index),temp_return,TestWindow, pval(1));
        e1_001 = loss_VaR(VaR1(:,2,index),temp_return,TestWindow, pval(2));           
        temp_loss(index,:) = [mean(e1_005,2) mean(e1_001,2)];
    end 
    loss(ii_var,:) = [mean(temp_loss(:,1)) mean(temp_loss(:,2))];
end
matrix2latex(loss','loss_N5.tex', 'format','%.3f')

save(strcat('sim_VaR_backtesting_dmtest_count_N', num2str(N),'.mat'));