function [u raw_u] = simfunc_Gaussian(theta,other)
% function [u raw_u] = simfunc_Gaussian(rho,s)
%
% Function to simulate data from the Gaussian copula
%
% INPUTS:   theta, a scalar inside (-1,1), the parameter of the Gaussian copula
%           other, a 3x1 vector containing other information = [T,N,seed]
%
% OUTPUTS:  u, a TxN matrix of the EDF-transforms of draws from the Gaussian copula (used in estimation)
%           raw_u, a TxN matrix of the original draws from the Gaussian copula
%
%  Dong Hwan Oh and Andrew J. Patton
%
%  22 October 2013
%
% This code was developed for the following paper:
%
% Oh, D.H. and A.J. Patton, 2013, "Simulated Method of Moments Estimation
% for Copula-Based Multivariate Models," Journal of the American
% Statistical Association, 108(502), 689-700.

T = other(1);
N = other(2);
seed = other(3);

rho = (ones(N,N)-eye(N)) * theta;
rho = rho + eye(N);  % converting theta to a correlation matrix

rand('state', seed) ;
randn('state', seed) ;

raw_u = copularnd('Gaussian',rho,T);
u = tiedrank(raw_u)/(T+1);

